From da15176d0d22a8b76f22722587941a9b76a48b8d Mon Sep 17 00:00:00 2001
From: Peter Smith <peter.b.smith@fujitsu.com>
Date: Thu, 1 Feb 2024 11:11:37 +1100
Subject: [PATCH v2] Fix pg_upgrade test comment

---
 src/bin/pg_upgrade/t/004_subscription.pl | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/bin/pg_upgrade/t/004_subscription.pl b/src/bin/pg_upgrade/t/004_subscription.pl
index 792f221..2d54313 100644
--- a/src/bin/pg_upgrade/t/004_subscription.pl
+++ b/src/bin/pg_upgrade/t/004_subscription.pl
@@ -109,7 +109,7 @@ $old_sub->stop;
 # Check that pg_upgrade is successful when all tables are in ready or in
 # init state (tab_upgraded1 table is in ready state and tab_upgraded2 table is
 # in init state) along with retaining the replication origin's remote lsn
 # and subscription's running status.
 # ------------------------------------------------------
 command_ok(
 	[
@@ -137,15 +137,15 @@ $publisher->safe_psql(
 
 $new_sub->start;
 
-# The subscription's running status and failover option should be preserved.
-# Old subscription regress_sub1 should have enabled and failover as true while
-# old subscription regress_sub2 should have enabled and failover as false.
+# The subscription's running status and failover option should be preserved
+# in the upgraded instance. So regress_sub1 should still have subenabled,subfailover
+# set to true, while regress_sub2 should have both set to false.
 $result =
   $new_sub->safe_psql('postgres',
 	"SELECT subname, subenabled, subfailover FROM pg_subscription ORDER BY subname");
 is( $result, qq(regress_sub1|t|t
 regress_sub2|f|f),
-	"check that the subscription's running status are preserved");
+	"check that the subscription's running status and failover are preserved");
 
 my $sub_oid = $new_sub->safe_psql('postgres',
 	"SELECT oid FROM pg_subscription WHERE subname = 'regress_sub2'");
@@ -109,7 +109,7 @@ $old_sub->stop;
 # init state (tab_upgraded1 table is in ready state and tab_upgraded2 table is
 # in init state) along with retaining the replication origin's remote lsn
-# and subscription's running status.
+# and subscription's running status and failover option.
 # ------------------------------------------------------
 command_ok(
-- 
1.8.3.1

